==> websvn-2.3.3-8-any.pkg.tar.xz: srv/http/websvn/languages/macedonian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// macedonian.php
// Ivica Eftimovski <ieftimovski@gmail.com>
//
// Macedonian language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "mk"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Macedonian";
$lang["LANGUAGENAMENATIVE"] = "Македонски";
$lang["LANGUAGENAMEHTML"] = "&#1052;&#1072;&#1082;&#1077;&#1076;&#1086;&#1085;&#1089;&#1082;&#1080;";

$lang["LOG"] = "Забелешка";
$lang["DIFF"] = "Разлика";

$lang["NOREP"] = "Репозиторот не е зададен.";
$lang["NOPATH"] = "Патот не е најден.";
$lang["NOACCESS"] = "Вие ги немате неопходните овластувањата да го прегледате оваа содржина.";
$lang["RESTRICTED"] = "Влезот е рестриктиран.";
$lang["SUPPLYREP"] = "Ве молиме дефинирајте репозитар во include/config.php користејки го <code>\$config->parentPath</code> или <code>\$config->addRepository</code>. Погледнете го упаството за инсталирање за подетален опис.";

$lang["DIFFREVS"] = "Разлика помеѓу ревизии";
$lang["AND"] = "и";
$lang["REV"] = "Ревизија";
$lang["LINE"] = "Линија";
$lang["LINENO"] = "Линија Бр.";
$lang["SHOWENTIREFILE"] = "Прикажи ја целата датотека";
$lang["SHOWCOMPACT"] = "Прикажи ги само деловите со разлики";
$lang["IGNOREWHITESPACE"] = "Игнорирај ги празните места";
$lang["REGARDWHITESPACE"] = "Забележи ги празните места";

$lang["LISTING"] = "Содржина на директориум";
$lang["FILEDETAIL"] = "Детали";
$lang["VIEWAS"] = "Види го како";
$lang["DIFFPREV"] = "Спореди со предходно";
$lang["BLAME"] = "Обвини";
$lang["BLAMEFOR"] = "Информација за обвинувањето на ревизијата";

$lang["REVINFO"] = "Информација за ревизијата";
$lang["GOYOUNGEST"] = "Оди на најновата ревизија";
$lang["LASTMOD"] = "Последна промена";
$lang["LOGMSG"] = "Порака во забелешката";
$lang["CHANGES"] = "Промени";
$lang["SHOWCHANGED"] = "Прикажи ги променетите датотеки";
$lang["HIDECHANGED"] = "Скриј ги променетите датотеки";
$lang["NEWFILES"] = "Нови датотеки";
$lang["CHANGEDFILES"] = "Променети датотеки";
$lang["DELETEDFILES"] = "Избришани датотеки";
$lang["VIEWLOG"] = "Видете забелешки";
$lang["PATH"] = "Пат";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Старост";
$lang["CURDIR"] = "Сегашен Директориум";
$lang["TARBALL"] = "Tar-архива";
$lang["DOWNLOAD"] = "Симнете";

$lang["PREV"] = "Предходно";
$lang["NEXT"] = "Следно";
$lang["SHOWALL"] = "Покажи ги сите";

$lang["BADCMD"] = "Грешка при извршување на команданта";
$lang["UNKNOWNREVISION"] = "Ревизијата не е најдена";

$lang["POWERED"] = "Работи на <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion Репозитар";
$lang["SERVER"] = "Subversion Сервер";

$lang["FILTER"] = "Опции на филтерот";
$lang["STARTLOG"] = "Од ревизија";
$lang["ENDLOG"] = "До ревизија";
$lang["MAXLOG"] = "Максимум ревизии";
$lang["SEARCHLOG"] = "Пребарај историја за";
$lang["CLEARLOG"] = "Избриши го сегашниот филтер";
$lang["MORERESULTS"] = "Најди повеќе парови...";
$lang["NORESULTS"] = "Нема забелешки кој одговараат со Вашето барање";
$lang["NOMORERESULTS"] = "Нема повеќе забелешки кој одговараат со Вашето барање";
$lang["NOPREVREV"] = "Нема предходни ревизии";

$lang["RSSFEEDTITLE"] = "WebSVN RSS вести";
$lang["FILESMODIFIED"] = "датотека/ки со промена";
$lang["RSSFEED"] = "RSS вести";

$lang["DAYLETTER"] = "д";
$lang["HOURLETTER"] = "ч";
$lang["MINUTELETTER"] = "м";
$lang["SECONDLETTER"] = "с";

$lang["GO"] = "Изврши";

$lang["PATHCOMPARISON"] = "Споредба на патишта";
$lang["COMPAREPATHS"] = "Спореди патишта";
$lang["COMPAREREVS"] = "Спореди ревизии";
$lang["PROPCHANGES"] = "Променети својства:";
$lang["CONVFROM"] = "Оваа споредба прикажува промени битни за промена на патот ";
$lang["TO"] = "во";
$lang["REVCOMP"] = "Обратна споредба";
$lang["COMPPATH"] = "Спореди пат:";
$lang["WITHPATH"] = "Со пат:";
$lang["FILEDELETED"] = "Датотеката е избришана";
$lang["FILEADDED"] = "Нова датотека";

==> websvn-2.6.1-1-any.pkg.tar.xz: srv/http/websvn/languages/macedonian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// macedonian.php
// Ivica Eftimovski <ieftimovski@gmail.com>
//
// Macedonian language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "mk"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Macedonian";
$lang["LANGUAGENAMENATIVE"] = "Македонски";
$lang["LANGUAGENAMEHTML"] = "&#1052;&#1072;&#1082;&#1077;&#1076;&#1086;&#1085;&#1089;&#1082;&#1080;";

$lang["LOG"] = "Забелешка";
$lang["DIFF"] = "Разлика";

$lang["NOREP"] = "Репозиторот не е зададен.";
$lang["NOPATH"] = "Патот не е најден.";
$lang["NOACCESS"] = "Вие ги немате неопходните овластувањата да го прегледате оваа содржина.";
$lang["RESTRICTED"] = "Влезот е рестриктиран.";
$lang["SUPPLYREP"] = "Ве молиме дефинирајте репозитар во include/config.php користејки го <code>\$config->parentPath</code> или <code>\$config->addRepository</code>. Погледнете го упаството за инсталирање за подетален опис.";

$lang["DIFFREVS"] = "Разлика помеѓу ревизии";
$lang["AND"] = "и";
$lang["REV"] = "Ревизија";
$lang["LINE"] = "Линија";
$lang["LINENO"] = "Линија Бр.";
$lang["SHOWENTIREFILE"] = "Прикажи ја целата датотека";
$lang["SHOWCOMPACT"] = "Прикажи ги само деловите со разлики";
$lang["IGNOREWHITESPACE"] = "Игнорирај ги празните места";
$lang["REGARDWHITESPACE"] = "Забележи ги празните места";

$lang["LISTING"] = "Содржина на директориум";
$lang["FILEDETAIL"] = "Детали";
$lang["VIEWAS"] = "Види го како";
$lang["DIFFPREV"] = "Спореди со предходно";
$lang["BLAME"] = "Обвини";
$lang["BLAMEFOR"] = "Информација за обвинувањето на ревизијата";

$lang["REVINFO"] = "Информација за ревизијата";
$lang["GOYOUNGEST"] = "Оди на најновата ревизија";
$lang["LASTMOD"] = "Последна промена";
$lang["LOGMSG"] = "Порака во забелешката";
$lang["CHANGES"] = "Промени";
$lang["SHOWCHANGED"] = "Прикажи ги променетите датотеки";
$lang["HIDECHANGED"] = "Скриј ги променетите датотеки";
$lang["NEWFILES"] = "Нови датотеки";
$lang["CHANGEDFILES"] = "Променети датотеки";
$lang["DELETEDFILES"] = "Избришани датотеки";
$lang["VIEWLOG"] = "Видете забелешки";
$lang["PATH"] = "Пат";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Старост";
$lang["CURDIR"] = "Сегашен Директориум";
$lang["TARBALL"] = "Tar-архива";
$lang["DOWNLOAD"] = "Симнете";

$lang["PREV"] = "Предходно";
$lang["NEXT"] = "Следно";
$lang["SHOWALL"] = "Покажи ги сите";

$lang["BADCMD"] = "Грешка при извршување на команданта";
$lang["UNKNOWNREVISION"] = "Ревизијата не е најдена";

$lang["POWERED"] = "Работи на <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion Репозитар";
$lang["SERVER"] = "Subversion Сервер";

$lang["FILTER"] = "Опции на филтерот";
$lang["STARTLOG"] = "Од ревизија";
$lang["ENDLOG"] = "До ревизија";
$lang["MAXLOG"] = "Максимум ревизии";
$lang["SEARCHLOG"] = "Пребарај историја за";
$lang["CLEARLOG"] = "Избриши го сегашниот филтер";
$lang["MORERESULTS"] = "Најди повеќе парови...";
$lang["NORESULTS"] = "Нема забелешки кој одговараат со Вашето барање";
$lang["NOMORERESULTS"] = "Нема повеќе забелешки кој одговараат со Вашето барање";
$lang["NOPREVREV"] = "Нема предходни ревизии";

$lang["RSSFEEDTITLE"] = "WebSVN RSS вести";
$lang["FILESMODIFIED"] = "датотека/ки со промена";
$lang["RSSFEED"] = "RSS вести";

$lang["DAYLETTER"] = "д";
$lang["HOURLETTER"] = "ч";
$lang["MINUTELETTER"] = "м";
$lang["SECONDLETTER"] = "с";

$lang["GO"] = "Изврши";

$lang["PATHCOMPARISON"] = "Споредба на патишта";
$lang["COMPAREPATHS"] = "Спореди патишта";
$lang["COMPAREREVS"] = "Спореди ревизии";
$lang["PROPCHANGES"] = "Променети својства:";
$lang["CONVFROM"] = "Оваа споредба прикажува промени битни за промена на патот ";
$lang["TO"] = "во";
$lang["REVCOMP"] = "Обратна споредба";
$lang["COMPPATH"] = "Спореди пат:";
$lang["WITHPATH"] = "Со пат:";
$lang["FILEDELETED"] = "Датотеката е избришана";
$lang["FILEADDED"] = "Нова датотека";

$lang['SEARCH'] = "Пребарување";
$lang['SEARCH_PLACEHOLDER'] = "Пребарувајте предмети овде";
$lang['NOITEMSFOUND'] = "Не се пронајдени предмети";
